
# Preferences
# https://www.renpy.org/doc/html/preferences.html

# Note: Only use default keyword for renpy preferences. Use settings.default for custom ones.
default preferences.text_cps = 40
default preferences.afm_time = 15
default preferences.pad_enabled = False
default preferences.renderer = "angle2" if renpy.windows else "gl2"
default preferences.gl_powersave = False

python early:
    if renpy.android:
        os.environ["RENPY_LESS_MEMORY"] = "1"

init python:
    settings.default("theme", "auto")
    settings.default("text_color_day", "#402313ff")
    settings.default("text_color_night", "#341c0fff")
    settings.default("text_outline", "#00000000")
    settings.default("tooltip", True)
    settings.default("tutorials", True)
    settings.default("preserve_aspect_ratio", True)
    settings.default("animations", True)

# Configuration
# https://www.renpy.org/doc/html/config.html

# Pre-Release related flags and variables
define config.searchpath = [os.environ["ANDROID_PUBLIC"]] if renpy.android else [config.gamedir, config.commondir]
define config.autoreload = False
define config.developer = "auto"
define config.console = True

# Game version and naming
define config.version = "1.43.0"
define compatible_version = 1.43
define config.name = "WT Silver"

# Application window settings
define config.window_title = "Witch Trainer: Silver (v{}) ({}) ({}-bit)".format(config.version, get_renderer(), renpy.bits)
define config.window_icon = "gui/icon.webp"
define config.screen_width = 1080
define config.screen_height = 600
define config.save_physical_size = True

# User interface settings
define config.layers = ["master", "transient", "screens", "overlay"]
define config.default_tag_layer = "screens"
define config.top_layers = ["interface"]
define config.transparent_tile = False
define config.narrator_menu = True
define config.hard_rollback_limit = 100
define config.history_length = 250
define config.mouse = {"default": [("interface/cursor.webp", 0, 0)]}
define config.help = None
define config.side_image_only_not_showing = True
define config.allow_underfull_grids = True
define config.crop_relative_default = False

# Graphics and cache settings
define config.gl2 = True
define config.gl_enable = True
define config.gl_resize = True
define config.gl_clear_color = "#000"
define config.hw_video = True
define config.nearest_neighbor = False
define config.atl_start_on_show = False # Enables compatibility for ATL behaviour after Ren'py 7.4.7
define config.use_drawable_resolution = (not renpy.android)
define config.drawable_resolution_text = True
define config.cache_surfaces = False
define config.image_cache_size = None
define config.image_cache_size_mb = 350
define config.load_before_transition = True
define config.imagemap_cache = True
define config.optimize_texture_bounds = True
define config.debug_image_cache = False
#define config.atl_one_frame = False
define config.mipmap_movies = (not renpy.android)
define config.mipmap_text = (not renpy.android)
define config.mipmap_dissolves = (not renpy.android)
define config.predict_screen_statements = False
define config.predict_screens = False

# Disable automatic image scanning
define config.automatic_images = None
define config.images_directory = None
init -1:
    define config.late_images_scan = True

# Saving and loading
define config.save_directory = "WTS"
define config.has_autosave = True
define config.autosave_on_quit = True
define config.autosave_on_choice = True
define config.autosave_frequency = 200
define config.autosave_slots = 12

# Sound and music
define config.has_sound = True
define config.has_music = True
define config.has_voice = False
define config.sound_sample_rate = 48000
define config.main_menu_music = "music/aquarium-by-kevin-macleod.ogg"

# Transitions
define config.enter_transition = f3
define config.exit_transition = f3
define config.intra_transition = d1
define config.main_game_transition = f3
define config.game_main_transition = f3
define config.end_splash_transition = d3
define config.end_game_transition = fade
define config.after_load_transition = fade
define config.window_show_transition = d3
define config.window_hide_transition = d3
define config.adv_nvl_transition = d3
define config.nvl_adv_transition = d3
define config.enter_yesno_transition = None
define config.exit_yesno_transition = None
define config.enter_replay_transition = None
define config.exit_replay_transition = None
define config.say_attribute_transition = d3

# Garbage Collector
define config.manage_gc = True
define config.gc_thresholds = (25000, 10, 10)
define config.idle_gc_count = 10000
define config.gc_print_unreachable = False

################################################
##           Build configuration              ##
##      For information please refer to:      ##
## https://www.renpy.org/doc/html/build.html  ##
################################################

init python:
    build.name = "WTS"
    build.include_update = True
    build.include_old_themes = False
    build.exclude_empty_directories = True

    build.archive("scripts", "all")
    build.archive("characters", "all")
    build.archive("images", "all")
    build.archive("sounds", "all")
    build.archive("music", "all")
    build.archive("gui", "all")
    build.archive("old", "all")

    build.classify("game/scripts/**.rpy", "scripts")
    build.classify("game/scripts/**.rpyc", "scripts")
    build.classify("old-game/scripts/**.rpy", "old")
    build.classify("old-game/scripts/**.rpyc", "old")
    build.classify("game/images.whitespace", "scripts")
    build.classify("game/characters/**.webp", "characters")
    build.classify("game/images/**.webp", "images")
    build.classify("game/images/**.webm", "images")
    build.classify("game/sounds/**.ogg", "sounds")
    build.classify("game/music/**.ogg", "music")

    build.classify("game/gui/**", "gui")
    build.classify("game/interface/**.webp", "gui")
    build.classify("android-icon_*.png", "android gui")
    build.classify("android-presplash.jpg", "android gui")
    build.classify("icon.icns", "mac gui")
    build.classify("icon.ico", "windows gui")
    build.classify("game/presplash_*.png", "mac windows linux gui")
    build.classify("game/outfits/**", "mac windows linux")

    build.classify("**.py", None)
    build.classify("**.txt", None)
    build.classify("**.md", None)
    build.classify("**.png", None)
    build.classify("**.jpg", None)
    build.classify("**.jpeg", None)
    build.classify("**.json", None)
    build.classify("LICENSE", None)
    build.classify("**.bak", None)
    build.classify("**.old", None)
    build.classify("**~", None)
    build.classify("**.db", None)
    build.classify("**.zip", None)

    build.classify("cache/**", None)
    build.classify("game/saves/**", None)

